#!/bin/bash

cwd="$(dirname $0)"
cd "$cwd"

[ -r ~/.ilfattorc ] || exit 1
. ~/.ilfattorc

useragent="Firefox/3.0.14"

login_form_file=/tmp/login
cookies_file=/tmp/cookies

function login() {
    # get the login page
    curl -c "$cookies_file" -b "$cookies_file" -s -A "$useragent" \
    "http://www.ilfattoquotidiano.it/login/" | \
        grep -o '<form .*id="loginform-tml-page".*>.*</form>' > $login_form_file

    # login (this will retrieve the sessionid and the pdfreader cookies)
    curl -s -A "$useragent" \
        -L "/servizi/pdf/pdfselect.aspx" \
        -F 'log='"$username" \
        -F 'pwd='"$password" \
        -F 'wp-submit=Log In' \
        -F 'redirect_to=http://www.ilfattoquotidiano.it/wp-admin/' \
        -F 'testcookie=1' \
        -F '_wp_original_http_referer=' \
        -c "$cookies_file" -b "$cookies_file" \
        "http://www.ilfattoquotidiano.it/login/?action=login&instance=tml-page" > /dev/null
}

function download() {
    y=$1
    m=$2
    d=$3
    dow=$4
    if ! [ $dow = 1 ]; then
        pdf_file="ilfatto-$y$m$d.pdf"
        if ! [ -r "$pdf_file" ]; then
            pdf_url="http://www.ilfattoquotidiano.it/openpdf/?n=$y$m$d"
            curl -b "$cookies_file" -A "$useragent" "$pdf_url" > "$pdf_file"
        fi
    fi
}


if ! [ -z $1 ]; then
    # get the starting date in the format yyyymmdd
    last_yy=$(echo $1 | sed 's/\(....\)..../\1/')
    last_mm=$(echo $1 | sed 's/....\(..\)../\1/')
    last_dd=$(echo $1 | sed 's/......\(..\)/\1/')

    # set the ending date
    yy=$last_yy
    mm=$last_mm
    dd=$last_dd
else
    # get the last issue and calculate the starting date
    last=$(ls -1 ilfatto-*.pdf | tail -n1)
    if [ -z $last ]; then
        last_yy=$(date +%Y)
        last_mm=$(date +%-m)
        last_dd=$(date +%-d)
    else
        last_date=$(echo $last | grep -o '[[:digit:]]*')
        last_yy=$(echo $last_date | sed 's/\(....\)..../\1/')
        last_mm=$(echo $last_date | sed 's/....\(..\)../\1/')
        last_dd=$(echo $last_date | sed 's/......\(..\)/\1/')
    fi

    # today
    yy=$(date +%Y)
    mm=$(date +%-m)
    dd=$(date +%-d)
fi

# do login
login

# for each missing issue, download the file
$cwd/dates.rb '%Y %m %d' "$last_yy $last_mm $last_dd" "$yy $mm $dd" | \
while read y m d dow; do
    download $y $m $d $dow
done
